==> phpMinAdmin-1.7.0.zip: phpMinAdmin-1.7.0/lang/de.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Abmeldung erfolgreich.',
	'Invalid credentials.' => 'Ungültige Anmelde-Informationen.',
	'Server' => 'Server',
	'Username' => 'Benutzer',
	'Password' => 'Passwort',
	'Select database' => 'Datenbank auswählen',
	'Invalid database.' => 'Datenbank ungültig.',
	'Create new database' => 'Neue Datenbank',
	'Table has been dropped.' => 'Tabelle gelöscht.',
	'Table has been altered.' => 'Tabelle geändert.',
	'Table has been created.' => 'Tabelle erstellt.',
	'Alter table' => 'Tabelle ändern',
	'Create table' => 'Neue Tabelle erstellen',
	'Table name' => 'Name der Tabelle',
	'engine' => 'Motor',
	'collation' => 'Kollation',
	'Column name' => 'Spaltenname',
	'Type' => 'Typ',
	'Length' => 'Länge',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto-Inkrement',
	'Options' => 'Optionen',
	'Save' => 'Speichern',
	'Drop' => 'Löschen',
	'Database has been dropped.' => 'Datenbank gelöscht.',
	'Database has been created.' => 'Datenbank erstellt.',
	'Database has been renamed.' => 'Datenbank umbenannt.',
	'Database has been altered.' => 'Datenbank geändert.',
	'Alter database' => 'Datenbank ändern',
	'Create database' => 'Neue Datenbank',
	'SQL command' => 'SQL-Query',
	'Dump' => 'Export',
	'Logout' => 'Abmelden',
	'database' => 'Datenbank',
	'Use' => 'Benutzung',
	'No tables.' => 'Keine Tabellen.',
	'select' => 'zeigen',
	'Create new table' => 'Neue Tabelle',
	'Item has been deleted.' => 'Datensatz gelöscht.',
	'Item has been updated.' => 'Datensatz geändert.',
	'Item has been inserted.' => 'Datensatz hinzugefügt.',
	'Edit' => 'Ändern',
	'Insert' => 'Hinzufügen',
	'Save and insert next' => 'Speichern und nächsten hinzufügen',
	'Delete' => 'Löschen',
	'Database' => 'Datenbank',
	'Routines' => 'Prozeduren',
	'Indexes has been altered.' => 'Indizes geändert.',
	'Indexes' => 'Indizes',
	'Alter indexes' => 'Indizes ändern',
	'Add next' => 'Hinzufügen',
	'Language' => 'Sprache',
	'Select' => 'Daten zeigen von',
	'New item' => 'Neuer Datensatz',
	'Search' => 'Suchen',
	'Sort' => 'Ordnen',
	'DESC' => 'absteigend',
	'Limit' => 'Begrenzung',
	'No rows.' => 'Keine Daten.',
	'Action' => 'Aktion',
	'edit' => 'ändern',
	'Page' => 'Seite',
	'Query executed OK, %d row(s) affected.' => array('Abfrage ausgeführt, %d Datensatz betroffen.', 'Abfrage ausgeführt, %d Datensätze betroffen.'),
	'Error in query' => 'Fehler in der SQL-Abfrage',
	'Execute' => 'Ausführen',
	'Table' => 'Tabelle',
	'Foreign keys' => 'Fremdschlüssel',
	'Triggers' => 'Trigger',
	'View' => 'View',
	'Unable to select the table' => 'Tabelle kann nicht ausgewählt werden',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token ungültig. Bitte die Formulardaten erneut abschicken.',
	'Comment' => 'Kommentar',
	'Default values has been set.' => 'Standard Vorgabewerte sind erstellt worden.',
	'Default values' => 'Vorgabewerte festlegen',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Spaltenkomentare zeigen',
	'%d byte(s)' => array('%d Byte', '%d Bytes'),
	'No commands to execute.' => 'Kein Kommando vorhanden.',
	'Unable to upload a file.' => 'Unmöglich Dateien hochzuladen.',
	'File upload' => 'Datei importieren',
	'File uploads are disabled.' => 'Importieren von Dateien abgeschaltet.',
	'Routine has been called, %d row(s) affected.' => array('Kommando SQL ausgeführt, %d Datensatz betroffen.', 'Kommando SQL ausgeführt, %d Datensätze betroffen.'),
	'Call' => 'Aufrufen',
	'No MySQL extension' => 'Keine MySQL-Erweiterungen installiert',
	'None of supported PHP extensions (%s) are available.' => 'Keine der unterstützten PHP-Erweiterungen (%s) ist vorhanden.',
	'Sessions must be enabled.' => 'Sitzungen müssen aktiviert sein.',
	'Session expired, please login again.' => 'Sitzungsdauer abgelaufen, bitte erneut anmelden.',
	'Text length' => 'Textlänge',
	'Syntax highlighting' => 'Syntax highlighting',
	'Foreign key has been dropped.' => 'Fremdschlüssel gelöscht.',
	'Foreign key has been altered.' => 'Fremdschlüssel geändert.',
	'Foreign key has been created.' => 'Fremdschlüssel erstellt.',
	'Foreign key' => 'Fremdschlüssel',
	'Target table' => 'Zieltabelle',
	'Change' => 'Ändern',
	'Source' => 'Ursprung',
	'Target' => 'Ziel',
	'Add column' => 'Spalte hinzufügen',
	'Alter' => 'Ändern',
	'Add foreign key' => 'Fremdschlüssel hinzufügen',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index-Typ',
	'Column (length)' => 'Spalte (Länge)',
	'View has been dropped.' => 'View gelöscht.',
	'View has been altered.' => 'View geändert.',
	'View has been created.' => 'View erstellt.',
	'Alter view' => 'View ändern',
	'Create view' => 'Neue View erstellen',
	'Name' => 'Name',
	'Process list' => 'Prozessliste',
	'%d process(es) has been killed.' => array('%d Prozess gestoppt.', '%d Prozesse gestoppt.'),
	'Kill' => 'Anhalten',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Name des Parameters',
	'Database schema' => 'Datenbankschema',
	'Create procedure' => 'Neue Prozedur',
	'Create function' => 'Neue Funktion',
	'Routine has been dropped.' => 'Prozedur gelöscht.',
	'Routine has been altered.' => 'Prozedur geändert.',
	'Routine has been created.' => 'Prozedur erstellt.',
	'Alter function' => 'Funktion ändern',
	'Alter procedure' => 'Prozedur ändern',
	'Return type' => 'Typ des Rückgabewertes',
	'Add trigger' => 'Trigger hinzufügen',
	'Trigger has been dropped.' => 'Trigger gelöscht.',
	'Trigger has been altered.' => 'Trigger geändert.',
	'Trigger has been created.' => 'Trigger erstellt.',
	'Alter trigger' => 'Trigger ändern',
	'Create trigger' => 'Trigger hinzufügen',
	'Time' => 'Zeitpunkt',
	'Event' => 'Ereignis',
	'%d row(s)' => array('%d Datensatz', '%d Datensätze'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Entfernen',
	'Are you sure?' => 'Sind Sie sicher ?',
	'Privileges' => 'Rechte',
	'Create user' => 'Neuer Benutzer',
	'User has been dropped.' => 'Benutzer gelöscht.',
	'User has been altered.' => 'Benutzer geändert.',
	'User has been created.' => 'Benutzer erstellt.',
	'Hashed' => 'Gehashed',
	'Column' => 'Spalte',
	'Routine' => 'Routine',
	'Grant' => 'Erlauben',
	'Revoke' => 'Verbieten',
	'Error during deleting' => 'Fehler beim Löschvorgang',
	'%d item(s) have been deleted.' => array('%d Artikel gelöscht.', '%d Artikel gelöscht.'),
	'all' => 'alle',
	'Delete selected' => 'Markierte löschen',
	'MySQL version: %s through PHP extension %s' => 'Version MySQL: %s, Zugriff unter Benutzung der PHP-Erweiterung %s',
	'around %d row(s)' => array('ungefähren %d Datensatz', 'ungefähren %d Datensätze'),
	'Logged as: %s' => 'Angemeldet als: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST data zu gross. Reduzieren Sie die Grösse oder vergrössern Sie den Wert "post_max_size" in der Konfiguration.',
	'Move up' => 'Nach oben',
	'Move down' => 'Nach unten',
	'Export' => 'Exportieren',
	'skip' => 'ignorieren',
	'Tables' => 'Tabellen',
	'Structure' => 'Struktur',
	'Data' => 'Daten',
	'Output' => 'Ausgabe',
	'open' => 'zeigen',
	'save' => 'speichern',
	'Format' => 'Format',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'Functions' => 'Funktionen',
	'Aggregation' => 'Aggregationen',
	'Truncate result' => 'Resultat abschneiden',
	'Export selected' => 'Markierte exportieren',
	'Export result' => 'Resultat exportieren',
);

==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/de.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => 'Abmeldung erfolgreich.',
	'Invalid credentials.' => 'Ungültige Anmelde-Informationen.',
	'Server' => 'Server',
	'Username' => 'Benutzer',
	'Password' => 'Passwort',
	'Select database' => 'Datenbank auswählen',
	'Invalid database.' => 'Datenbank ungültig.',
	'Create new database' => 'Neue Datenbank',
	'Table has been dropped.' => 'Tabelle entfernt.',
	'Table has been altered.' => 'Tabelle geändert.',
	'Table has been created.' => 'Tabelle erstellt.',
	'Alter table' => 'Tabelle ändern',
	'Create table' => 'Neue Tabelle erstellen',
	'Table name' => 'Name der Tabelle',
	'engine' => 'Motor',
	'collation' => 'Kollation',
	'Column name' => 'Spaltenname',
	'Type' => 'Typ',
	'Length' => 'Länge',
	'NULL' => 'NULL',
	'Auto Increment' => 'Auto-Inkrement',
	'Options' => 'Optionen',
	'Save' => 'Speichern',
	'Drop' => 'Entfernen',
	'Database has been dropped.' => 'Datenbank entfernt.',
	'Database has been created.' => 'Datenbank erstellt.',
	'Database has been renamed.' => 'Datenbank umbenannt.',
	'Database has been altered.' => 'Datenbank geändert.',
	'Alter database' => 'Datenbank ändern',
	'Create database' => 'Neue Datenbank',
	'SQL command' => 'SQL-Query',
	'Dump' => 'Export',
	'Logout' => 'Abmelden',
	'database' => 'Datenbank',
	'Use' => 'Benutzung',
	'No tables.' => 'Keine Tabellen.',
	'select' => 'zeigen',
	'Create new table' => 'Neue Tabelle',
	'Item has been deleted.' => 'Datensatz gelöscht.',
	'Item has been updated.' => 'Datensatz geändert.',
	'Item has been inserted.' => 'Datensatz hinzugefügt.',
	'Edit' => 'Ändern',
	'Insert' => 'Hinzufügen',
	'Save and insert next' => 'Speichern und nächsten hinzufügen',
	'Delete' => 'Entfernen',
	'Database' => 'Datenbank',
	'Routines' => 'Prozeduren',
	'Indexes has been altered.' => 'Indizes geändert.',
	'Indexes' => 'Indizes',
	'Alter indexes' => 'Indizes ändern',
	'Add next' => 'Hinzufügen',
	'Language' => 'Sprache',
	'Select' => 'Daten zeigen von',
	'New item' => 'Neuer Datensatz',
	'Search' => 'Suchen',
	'Sort' => 'Ordnen',
	'DESC' => 'absteigend',
	'Limit' => 'Begrenzung',
	'No rows.' => 'Keine Daten.',
	'Action' => 'Aktion',
	'edit' => 'ändern',
	'Page' => 'Seite',
	'Query executed OK, %d row(s) affected.' => array('Abfrage ausgeführt, %d Datensatz betroffen.', 'Abfrage ausgeführt, %d Datensätze betroffen.'),
	'Error in query' => 'Fehler in der SQL-Abfrage',
	'Execute' => 'Ausführen',
	'Table' => 'Tabelle',
	'Foreign keys' => 'Fremdschlüssel',
	'Triggers' => 'Trigger',
	'View' => 'View',
	'Unable to select the table' => 'Tabelle kann nicht ausgewählt werden',
	'Invalid CSRF token. Send the form again.' => 'CSRF Token ungültig. Bitte die Formulardaten erneut abschicken.',
	'Comment' => 'Kommentar',
	'Default values has been set.' => 'Standard Vorgabewerte sind erstellt worden.',
	'Default values' => 'Vorgabewerte festlegen',
	'BOOL' => 'BOOL',
	'Show column comments' => 'Spaltenkomentare zeigen',
	'%d byte(s)' => array('%d Byte', '%d Bytes'),
	'No commands to execute.' => 'Kein Kommando vorhanden.',
	'Unable to upload a file.' => 'Unmöglich Dateien hochzuladen.',
	'File upload' => 'Datei importieren',
	'File uploads are disabled.' => 'Importieren von Dateien abgeschaltet.',
	'Routine has been called, %d row(s) affected.' => array('Kommando SQL ausgeführt, %d Datensatz betroffen.', 'Kommando SQL ausgeführt, %d Datensätze betroffen.'),
	'Call' => 'Aufrufen',
	'No MySQL extension' => 'Keine MySQL-Erweiterungen installiert',
	'None of supported PHP extensions (%s) are available.' => 'Keine der unterstützten PHP-Erweiterungen (%s) ist vorhanden.',
	'Sessions must be enabled.' => 'Sitzungen müssen aktiviert sein.',
	'Session expired, please login again.' => 'Sitzungsdauer abgelaufen, bitte erneut anmelden.',
	'Text length' => 'Textlänge',
	'Syntax highlighting' => 'Syntax highlighting',
	'Foreign key has been dropped.' => 'Fremdschlüssel entfernt.',
	'Foreign key has been altered.' => 'Fremdschlüssel geändert.',
	'Foreign key has been created.' => 'Fremdschlüssel erstellt.',
	'Foreign key' => 'Fremdschlüssel',
	'Target table' => 'Zieltabelle',
	'Change' => 'Ändern',
	'Source' => 'Ursprung',
	'Target' => 'Ziel',
	'Add column' => 'Spalte hinzufügen',
	'Alter' => 'Ändern',
	'Add foreign key' => 'Fremdschlüssel hinzufügen',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Index-Typ',
	'Column (length)' => 'Spalte (Länge)',
	'View has been dropped.' => 'View entfernt.',
	'View has been altered.' => 'View geändert.',
	'View has been created.' => 'View erstellt.',
	'Alter view' => 'View ändern',
	'Create view' => 'Neue View erstellen',
	'Name' => 'Name',
	'Process list' => 'Prozessliste',
	'%d process(es) has been killed.' => array('%d Prozess gestoppt.', '%d Prozesse gestoppt.'),
	'Kill' => 'Anhalten',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Name des Parameters',
	'Database schema' => 'Datenbankschema',
	'Create procedure' => 'Neue Prozedur',
	'Create function' => 'Neue Funktion',
	'Routine has been dropped.' => 'Prozedur entfernt.',
	'Routine has been altered.' => 'Prozedur geändert.',
	'Routine has been created.' => 'Prozedur erstellt.',
	'Alter function' => 'Funktion ändern',
	'Alter procedure' => 'Prozedur ändern',
	'Return type' => 'Typ des Rückgabewertes',
	'Add trigger' => 'Trigger hinzufügen',
	'Trigger has been dropped.' => 'Trigger entfernt.',
	'Trigger has been altered.' => 'Trigger geändert.',
	'Trigger has been created.' => 'Trigger erstellt.',
	'Alter trigger' => 'Trigger ändern',
	'Create trigger' => 'Trigger hinzufügen',
	'Time' => 'Zeitpunkt',
	'Event' => 'Ereignis',
	'MySQL version: %s through PHP extension %s' => 'Version MySQL: %s, mit PHP-Erweiterung %s',
	'%d row(s)' => array('%d Datensatz', '%d Datensätze'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Entfernen',
	'Are you sure?' => 'Sind Sie sicher ?',
	'Privileges' => 'Rechte',
	'Create user' => 'Neuer Benutzer',
	'User has been dropped.' => 'Benutzer entfernt.',
	'User has been altered.' => 'Benutzer geändert.',
	'User has been created.' => 'Benutzer erstellt.',
	'Hashed' => 'Gehashed',
	'Column' => 'Spalte',
	'Routine' => 'Routine',
	'Grant' => 'Erlauben',
	'Revoke' => 'Verbieten',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST data zu gross. Reduzieren Sie die Grösse oder vergrössern Sie den Wert "post_max_size" in der Konfiguration.',
	'Logged as: %s' => 'Angemeldet als: %s',
	'Move up' => 'Nach oben',
	'Move down' => 'Nach unten',
	'Functions' => 'Funktionen',
	'Aggregation' => 'Aggregationen',
	'Export' => 'Exportieren',
	'Output' => 'Ausgabe',
	'open' => 'zeigen',
	'save' => 'speichern',
	'Format' => 'Format',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'skip' => 'ignorieren',
	'Tables' => 'Tabellen',
	'Structure' => 'Struktur',
	'Data' => 'Daten',
	'Event has been dropped.' => 'Ereignis entfernt.',
	'Event has been altered.' => 'Ereignis geändert.',
	'Event has been created.' => 'Ereignis erstellt.',
	'Alter event' => 'Ereignis ändern',
	'Create event' => 'Ereignis erstellen',
	'At given time' => 'Zur angegebenen Zeit',
	'Every' => 'Jede',
	'Events' => 'Ereignisse',
	'Schedule' => 'Zeitplan',
	'Start' => 'Start',
	'End' => 'Ende',
	'Status' => 'Status',
	'On completion preserve' => 'Nach der Ausführung erhalten',
	'Tables and views' => 'Tabellen und Views',
	'Data Length' => 'Datengrösse',
	'Index Length' => 'Indexgrösse',
	'Data Free' => 'Freier Bereich',
	'Collation' => 'Collation',
	'Analyze' => 'Analysieren',
	'Optimize' => 'Optimisieren',
	'Check' => 'Prüfen',
	'Repair' => 'Reparieren',
	'Truncate' => 'Entleeren (truncate)',
	'Tables have been truncated.' => 'Tabellen sind entleert worden (truncate).',
	'Rows' => 'Datensätze',
	',' => ' ',
	'Tables have been moved.' => 'Tabellen verschoben.',
	'Move to other database' => 'In andere Datenbank verschieben',
	'Move' => 'Verschieben',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Speichern und weiter bearbeiten',
	'clone' => 'klonen',
	'original' => 'original',
	'Tables have been dropped.' => 'Tabellen wurden entfernt (drop).',
	'%d item(s) have been affected.' => array('%d Artikel betroffen.', '%d Artikel betroffen.'),
	'whole result' => 'gesamtes Resultat',
	'Clone' => 'Klonen',
);
